github crates-io docs-rs ci

Cryptography Utils for Rust

Importing

The driver is available on crates-io. To use the driver in your application, simply add it to your project’s Cargo.toml.

[dependencies]
crypto-utils = "0.4.0"

How to use?

Check jsonwebtoken and sha modules.

All Feature flags

FeatureDescriptionDependenciesDefault
shaEnable support for the Sha1, Sha256 and Sha512 hashersha and sha2yes
jwtEnable support for the Json Web Token utilschrono, serde and jsonwebtokenyes

Modules

Module for creating and decoding json web token.
Module for creating sha1, sha256 and sha512 hashes.